//
//  SideBarController.m
//  HighWay
//
//  Created by SunLi on 16/6/30.
//  Copyright © 2016年 lb. All rights reserved.
//

#import "SideBarController.h"

#define CurrScreenHeight   [UIScreen mainScreen].bounds.size.height
// 屏幕大小尺寸
#define SCREENWIDTH [UIScreen mainScreen].bounds.size.width
#define SCREENHEIGHT [UIScreen mainScreen].bounds.size.height

@interface SideBarController()<UIScrollViewDelegate>

//滚动视图
@property(nonatomic, strong) UIScrollView *scrollView;
@property(nonatomic, assign) CGFloat scrollHeight;
@end

@implementation SideBarController
@synthesize menuColor = _menuColor;
@synthesize isOpen = _isOpen;

#pragma mark -
#pragma mark Init

- (SideBarController*)initWithImages:(NSArray*)images
{
    _scrollView = [[UIScrollView alloc]init];
    _scrollView.showsHorizontalScrollIndicator = NO;
    _scrollView.showsVerticalScrollIndicator = NO;
    _scrollView.delegate = self;
    _backgroundMenuView = [[UIView alloc] init];
    _menuColor = [UIColor whiteColor];
    _buttonList = [[NSMutableArray alloc] initWithCapacity:images.count];
    
    int index = 0;
    
    for (UIImage *image in [images copy]){
        UIButton *button = [UIButton buttonWithType:UIButtonTypeCustom];
        [button setImage:image forState:UIControlStateNormal];
        if (CurrScreenHeight >= 568.0f){
            button.frame = CGRectMake(10, 10 *(index+1) + (60 * index), 60, 60);
            _scrollHeight +=  10 + button.bounds.size.height;
        }else{
            button.frame = CGRectMake(10, 10 * (index+1) + (48 * index), 48, 48);
            _scrollHeight += 10 +  button.bounds.size.height;
        }
        //滚动视图的高度
        
        button.tag = index;
        [button addTarget:self action:@selector(onMenuButtonClick:) forControlEvents:UIControlEventTouchUpInside];
        [_buttonList addObject:button];
        ++index;
    }
    _scrollHeight += 10;//底部留出10的空间
    return self;
}

//
- (void)insertMenuButtonOnView:(UIView*)view yLoc:(CGFloat)yloc height:(CGFloat)height
{
    UITapGestureRecognizer *singleTap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(dismissMenu)];
    [_backgroundMenuView addGestureRecognizer:singleTap];
    
    for (UIButton *button in _buttonList){
        [_scrollView addSubview:button];
    }
    
    if (CurrScreenHeight >= 568.0f){
         _backgroundMenuView.frame = CGRectMake(SCREENWIDTH, yloc, 80, height);
        _scrollView.frame = CGRectMake(0, 0, 80, height);
        _scrollView.contentSize = CGSizeMake(80, _scrollHeight);
    }
    else{
         _backgroundMenuView.frame = CGRectMake(SCREENWIDTH, yloc, 68, height);
        _scrollView.frame = CGRectMake(0, 0, 68, height);
        _scrollView.contentSize = CGSizeMake(68, _scrollHeight);
    }
    _backgroundMenuView.backgroundColor = [UIColor colorWithRed:1 green:1 blue:1 alpha:0.6f];
    //_scrollView.backgroundColor = [UIColor colorWithRed:1 green:1 blue:1 alpha:0.6f];
    [_backgroundMenuView addSubview:_scrollView];
    [view addSubview:_backgroundMenuView];
}

#pragma mark -ScrollView delegate
- (void)scrollViewDidScroll:(UIScrollView *)scrollView{
    
}

#pragma mark Menu button action

- (void)dismissMenuWithSelection:(UIButton*)button
{
    [UIView animateWithDuration:0.3f
                          delay:0.0f
         usingSpringWithDamping:.2f
          initialSpringVelocity:10.f
                        options:0 animations:^{
                            button.transform = CGAffineTransformScale(CGAffineTransformIdentity, 1.2, 1.2);
                        }
                     completion:^(BOOL finished) {
                         [self dismissMenu];
                     }];
}

- (void)dismissMenu
{
    if (_isOpen)
    {
        _isOpen = !_isOpen;
        [self performDismissAnimation];
    }
}

- (void)showMenu
{
    if (!_isOpen)
    {
        _isOpen = !_isOpen;
        [self performSelectorInBackground:@selector(performOpenAnimation) withObject:nil];
    }
}

- (void)onMenuButtonClick:(UIButton*)button
{
    if ([self.delegate respondsToSelector:@selector(menuButtonClicked:)])
        [self.delegate menuButtonClicked:button.tag];
    [self dismissMenuWithSelection:button];
}

#pragma mark -
#pragma mark - Animations

- (void)performDismissAnimation
{
    //CGAffineTransformIdentity perform reset action for transform before
    [UIView animateWithDuration:0.4 animations:^{
        _backgroundMenuView.transform = CGAffineTransformTranslate(CGAffineTransformIdentity, 0, 0);
    }];
}

- (void)performOpenAnimation
{
    dispatch_async(dispatch_get_main_queue(), ^{
        [UIView animateWithDuration:0.4 animations:^{
            if (CurrScreenHeight >= 568.0f){
                _backgroundMenuView.transform = CGAffineTransformTranslate(CGAffineTransformIdentity, -80, 0);
            }
            else{
                _backgroundMenuView.transform = CGAffineTransformTranslate(CGAffineTransformIdentity, -68, 0);
            }
        }];
    });
    for (UIButton *button in _buttonList)
    {
        [NSThread sleepForTimeInterval:0.02f];
        dispatch_async(dispatch_get_main_queue(), ^{
            button.transform = CGAffineTransformTranslate(CGAffineTransformIdentity, 10, 0);
            [UIView animateWithDuration:0.3f
                                  delay:0.3f
                 usingSpringWithDamping:.3f
                  initialSpringVelocity:10.f
                                options:0 animations:^{
                                    button.transform = CGAffineTransformTranslate(CGAffineTransformIdentity, 0, 0);
                                }
                             completion:^(BOOL finished) {
                             }];
        });
    }
}

@end
